@@ -94,6 +94,7 @@ namespace pan
          std::string username;
          std::string password;
          std::string host;
+         std::string newsrc_filename;
          int port;
          int article_expiration_age;
          int max_connections;
@@ -335,6 +336,18 @@ namespace pan
       typedef std::vector<ArticleNode*> nodes_v;
       typedef std::vector<const ArticleNode*> const_nodes_v;
 
+      struct NodeWeakOrdering
+      {
+        typedef std::pair<Quark,ArticleNode*> nodes_t_element;
+
+        bool operator () (const nodes_t_element& a, const Quark& b) const {
+          return a.first < b;
+        }
+        bool operator () (const Quark& a, const nodes_t_element& b) const {
+          return a < b.first;
+        }
+      };
+
       struct GroupHeaders
       {
         int _ref;
