@@ -18,13 +18,15 @@
  */
 
 #include <config.h>
-#include <errno.h>
+#include <cerrno>
 #include <fstream>
 #include <map>
 #include <vector>
 #include <string>
 #include <cmath>
 extern "C" {
+  #include <sys/types.h> // for chmod
+  #include <sys/stat.h> // for chmod
   #include <glib/gi18n.h>
   #include <glib/gmessages.h> // for g_assert
 }
@@ -794,6 +796,7 @@ DataImpl :: save_headers (DataIO                       & data_io,
 
     success = !out->fail ();
     data_io.write_done (out);
+    save_group_xovers (data_io);
   }
 
   return success;
@@ -970,6 +973,7 @@ DataImpl :: add_score (const StringView           & section_wildmat,
     std::ofstream o (filename.c_str(), std::ofstream::app|std::ofstream::out);
     o << '\n' << str << '\n';
     o.close ();
+    ::chmod (filename.c_str(), 0600);
   }
 
   if (do_rescore)
@@ -998,9 +1002,11 @@ DataImpl :: comment_out_scorefile_line (const StringView    & filename,
   in.close ();
 
   // ..and back out again
-  std::ofstream o (filename.to_string().c_str(), std::ofstream::trunc|std::ofstream::out);
+  const std::string f (filename.str, filename.len);
+  std::ofstream o (f.c_str(), std::ofstream::trunc|std::ofstream::out);
   o << buf;
   o.close ();
+  ::chmod (f.c_str(), 0600);
 
   // rescore
   if (do_rescore)
