@@ -38,7 +38,7 @@ Article :: get_part_state () const
     part_state = SINGLE;
 
   // someone's posted a followup to a multipart
-  else if (!is_line_count_ge(250) && has_reply_leader(subject.to_string()))
+  else if (!is_line_count_ge(250) && has_reply_leader(subject.to_view()))
     part_state = SINGLE;
 
   // someone's posted a "000/124" info message
@@ -103,19 +103,19 @@ Article :: set_part_count (unsigned int count)
 }
 
 Article :: Part&
-Article :: get_part (size_t number)
+Article :: get_part (unsigned int number)
 {
   //std::cerr << LINE_ID << " parts.size() " << parts.size() << " number " << number << std::endl;
-  const size_t index (number - 1);
+  const unsigned int index (number - 1);
   assert (parts.size() > index);
   return parts[index];
 }
 
 const Article :: Part&
-Article :: get_part (size_t number) const
+Article :: get_part (unsigned int number) const
 {
   //std::cerr << LINE_ID << " parts.size() " << parts.size() << " number " << number << std::endl;
-  const size_t index (number - 1);
+  const unsigned int index (number - 1);
   assert (parts.size() > index);
   return parts[index];
 }
