@@ -327,7 +327,9 @@ namespace
 
 GUI :: ~GUI ()
 {
-  gtk_accel_map_save (get_accel_filename().c_str());
+  const std::string accel_filename (get_accel_filename());
+  gtk_accel_map_save (accel_filename.c_str());
+  chmod (accel_filename.c_str(), 0600);
 
   if (hpane)
     _prefs.set_int ("main-window-hpane-position", gtk_paned_get_position(GTK_PANED(hpane)));
@@ -723,8 +725,8 @@ void GUI :: do_rot13_selected_text ()
 void GUI :: on_progress_finished (Progress & p, int status)
 {
   TaskArticle * ta = dynamic_cast<TaskArticle*>(&p);
-  if (status==OK && ta && ta->get_article().message_id == latest_read_article.message_id)
-    _body_pane->set_article (latest_read_article);
+  if (status==OK && ta)
+    _body_pane->set_article (ta->get_article());
 }
 
 void GUI :: do_read_selected_article ()
@@ -732,7 +734,6 @@ void GUI :: do_read_selected_article ()
   const Article* article (_header_pane->get_first_selected_article ());
   if (article)
   {
-    latest_read_article = *article;
     Task * t = new TaskArticle (_data, _data, *article, _cache, _data, this);
     _queue.add_task (t, Queue::TOP);
 
@@ -1231,8 +1232,28 @@ namespace
       w = NULL;
     return w;
   }
+
+  gboolean grab_focus_idle (gpointer w)
+  {
+    gtk_widget_grab_focus (GTK_WIDGET(w));
+    return false;
+  }
 }
 
+void
+GUI :: notebook_page_switched_cb (GtkNotebook * notebook, GtkNotebookPage * page, gint page_num, gpointer user_data)
+{
+  GUI * gui = static_cast<GUI*>(user_data);
+  GtkWidget * w;
+  switch (page_num) {
+    case 0: w = gui->_group_pane->get_default_focus_widget(); break;
+    case 1: w = gui->_header_pane->get_default_focus_widget(); break;
+    case 2: w = gui->_body_pane->get_default_focus_widget(); break;
+    default: g_assert (0 && "invalid page reached!"); break;
+  }
+  g_idle_add (grab_focus_idle, w);
+}
+ 
 void GUI :: do_tabbed_layout (bool tabbed)
 {
   if (hpane) {
@@ -1270,6 +1291,7 @@ void GUI :: do_tabbed_layout (bool tabbed)
     gtk_notebook_append_page (n, header_w, gtk_label_new_with_mnemonic (_("_2. Header Pane")));
     gtk_notebook_append_page (n, body_w, gtk_label_new_with_mnemonic (_("_3. Body Pane")));
     gtk_notebook_set_tab_border (n, PAD_SMALL);
+    g_signal_connect (n, "switch-page", G_CALLBACK(notebook_page_switched_cb), this);
   }
   else
   {
@@ -1403,13 +1425,12 @@ void GUI :: do_read_selected_group ()
   const Quark group (_group_pane->get_selection ());
 
   // update the titlebar
-  if (group.empty())
-    gtk_window_set_title (get_window(_root), _("Pan"));
-  else {
-    char * buf = g_strdup_printf (_("Pan: %s"), group.c_str());
-    gtk_window_set_title (get_window(_root), buf);
-    g_free (buf);
+  std::string s (_("Pan"));
+  if (!group.empty()) {
+    s += ": ";
+    s += group.c_str();
   }
+  gtk_window_set_title (get_window(_root), s.c_str());
 
   // set the charset encoding based upon that group's default
   if (!group.empty()) {
@@ -1620,7 +1641,7 @@ GUI :: set_queue_size_label (unsigned int running,
   if (!size)
     g_snprintf (str, sizeof(str), _("No Tasks"));
   else
-    g_snprintf (str, sizeof(str), _("Tasks: %u/%u"), running, size);
+    g_snprintf (str, sizeof(str), "%s: %u/%u", _("Tasks"), running, size);
 
   // update the gui
   gtk_label_set_text (GTK_LABEL(_queue_size_label), str);
