@@ -169,7 +169,6 @@ namespace pan
       virtual void on_log_cleared () {}
 
     private: // Progress::Listener
-      Article latest_read_article;
       virtual void on_progress_finished (Progress&, int status);
 
     private:
@@ -222,6 +221,8 @@ namespace pan
 
       void score_add (int);
 
+      static void notebook_page_switched_cb (GtkNotebook*, GtkNotebookPage*, gint, gpointer);
+
     private:
       static void add_widget (GtkUIManager*, GtkWidget*, gpointer);
       static void server_list_dialog_destroyed_cb (GtkWidget*, gpointer);
