@@ -104,6 +104,7 @@ namespace pan
 
     public:
       GtkWidget* root () { return _root; }
+      GtkWidget* get_default_focus_widget() { return _tree_view; }
       GtkWidget* create_filter_entry ();
       const Article* get_first_selected_article () const;
       std::set<const Article*> get_full_selection () const;
@@ -138,7 +139,7 @@ namespace pan
       virtual void on_queue_connection_count_changed (Queue&, int count) { }
       virtual void on_queue_size_changed (Queue&, int active, int total) { }
       virtual void on_queue_online_changed (Queue&, bool online) { }
-      virtual void on_queue_error (Queue&, const std::string& message) { }
+      virtual void on_queue_error (Queue&, const StringView& message) { }
 
     private:
       virtual void on_cache_added (const Quark& mid);
@@ -212,7 +213,7 @@ namespace pan
           // lazy instantation... it's expensive and user might never sort by this key
           char* get_collated_author () const {
             if (!collated_author)
-                 collated_author = do_collate (article->author.to_view());
+                 collated_author = do_collate (short_author.to_view());
             return collated_author;
           }
 
