@@ -183,6 +183,7 @@ namespace
     GtkTextIter insert_iter;
     gtk_text_buffer_get_iter_at_mark (text_buffer, &insert_iter, mark);
     int char_offset (gtk_text_iter_get_offset (&insert_iter));
+    const int width_diff ((int)after.size() - (int)before.size());
 
     // swap the non-wrapped for the wrapped text
     gtk_text_buffer_delete (text_buffer, &line_begin_iter, &end_iter);
@@ -190,14 +191,14 @@ namespace
 
     // update the insert and selection_bound marks to
     // where they were before the swap
-    gtk_text_buffer_get_iter_at_offset (text_buffer, &insert_iter, char_offset);
+    gtk_text_buffer_get_iter_at_offset (text_buffer, &insert_iter, char_offset + width_diff);
     mark = gtk_text_buffer_get_mark (text_buffer, "insert");
     gtk_text_buffer_move_mark (text_buffer, mark, &insert_iter);
     mark = gtk_text_buffer_get_mark (text_buffer, "selection_bound");
     gtk_text_buffer_move_mark (text_buffer, mark, &insert_iter);
 
     // revalidate the insert_pos iterator
-    gtk_text_buffer_get_iter_at_offset (text_buffer, insert_pos, insert_iterator_pos);
+    gtk_text_buffer_get_iter_at_offset (text_buffer, insert_pos, insert_iterator_pos + width_diff);
 
     dampen_feedback = false;
   }
@@ -246,10 +247,10 @@ namespace
     { "save-draft", GTK_STOCK_SAVE, N_("Sa_ve Draft"), "<control>s", N_("Save as a Draft for Future Posting"), G_CALLBACK(do_save) },
     { "open-draft", GTK_STOCK_OPEN, N_("_Open Draft..."), "<control>o", N_("Open an Article Draft"), G_CALLBACK(do_open) },
     { "rewrap", GTK_STOCK_JUSTIFY_FILL, N_("Wrap _Now"), NULL, N_("Wrap the Article Body to 80 Columns"), G_CALLBACK(do_wrap) },
-    { "close", GTK_STOCK_CLOSE, N_("_Close"), NULL, N_("Close Window"), G_CALLBACK(do_close) },
-    { "cut", GTK_STOCK_CUT, N_("Cu_t"), NULL, N_("Cut Text"), G_CALLBACK(do_cut) },
-    { "copy", GTK_STOCK_COPY, N_("_Copy"), NULL, N_("Copy Text"), G_CALLBACK(do_copy) },
-    { "paste", GTK_STOCK_PASTE, N_("_Paste"), NULL, N_("Paste Text"), G_CALLBACK(do_paste) },
+    { "close", GTK_STOCK_CLOSE, NULL, NULL, NULL, G_CALLBACK(do_close) },
+    { "cut", GTK_STOCK_CUT, NULL, NULL, NULL, G_CALLBACK(do_cut) },
+    { "copy", GTK_STOCK_COPY, NULL, NULL, NULL, G_CALLBACK(do_copy) },
+    { "paste", GTK_STOCK_PASTE, NULL, NULL, NULL, G_CALLBACK(do_paste) },
     { "rot13", GTK_STOCK_REFRESH, N_("_Rot13"), NULL, N_("Rot13 Selected Text"), G_CALLBACK(do_rot13) },
     { "run-editor", GTK_STOCK_JUMP_TO, N_("Run _Editor"), "<control>e", NULL, G_CALLBACK(do_edit) },
     { "manage-editors", NULL, N_("_Manage Editor List..."), NULL, NULL, G_CALLBACK(do_editors) },
@@ -429,7 +430,7 @@ PostUI :: add_actions (GtkWidget * box)
     gtk_ui_manager_add_ui_from_string (_uim, fallback_post_ui, -1, &err);
   }
   if (err) {
-    Log::add_err_va (_("Error loading post.ui: \"%s\""), err->message);
+    Log::add_err_va (_("Error reading file \"%s\": %s"), filename, err->message);
     g_clear_error (&err);
   }
   g_free (filename);
@@ -1932,7 +1933,7 @@ PostUI :: PostUI (GtkWindow    * parent,
   // add the body text widget
   w = create_body_widget (_body_buf, _body_view, prefs);
   set_spellcheck_enabled (prefs.get_flag ("spellcheck-enabled", DEFAULT_SPELLCHECK_FLAG));
-  g_signal_connect (_body_buf, "insert-text", G_CALLBACK(text_was_inserted_cb), &_tm);
+  g_signal_connect_after (_body_buf, "insert-text", G_CALLBACK(text_was_inserted_cb), &_tm);
   gtk_box_pack_start (GTK_BOX(vbox), w, true, true, 0);
 
   set_message (message);
@@ -1972,6 +1973,7 @@ PostUI :: create_window (GtkWindow    * parent,
   {
     Profile profile;
     profile.username = g_get_real_name ();
+    /* xgettext: no-c-format */
     profile.attribution = _("On %d, %n wrote:");
     ProfileDialog d (data, g_get_real_name(), profile, GTK_WINDOW(parent));
     const bool got_profile (ProfileDialog :: run_until_valid_or_cancel (d));
