@@ -84,7 +84,7 @@ URL :: open (const Prefs& prefs, const char * url, Mode mode)
   else if (env == "windows") cmd = "rundll32 url.dll,FileProtocolHandler";
   else                       cmd = prefs.get_string (custom_key, custom_fallback);
 
-  cmd += std::string(" \"") + url + '"';
+  cmd += std::string(" \"") + tmp + '"';
   // std::cerr << __FILE__ << ':' << __LINE__ << " cmd [" << cmd << ']' << std::endl;
   GError * err (0);
   g_spawn_command_line_async (cmd.c_str(), &err);
