@@ -202,17 +202,10 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
 
       case NO_POSTING:
       case POSTING_FAILED:
+      case GROUP_NONEXISTENT:
          state = CMD_FAIL;
          break;
 
-      case GROUP_NONEXISTENT: {
-         std::string host;
-         _socket->get_host (host);
-         Log::add_err_va (_("Can't find group \%s\" on server \"%s\""), line.to_string().c_str(), host.c_str());
-         state = CMD_FAIL;
-         break;
-      }
-
       case XOVER_FOLLOWS:
       case ARTICLE_FOLLOWS:
       case NEWGROUPS_FOLLOWS:
@@ -225,8 +218,20 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
       case NO_GROUP_SELECTED:
       case ERROR_CMD_NOT_UNDERSTOOD:
       case ERROR_CMD_NOT_SUPPORTED:
-      case NO_PERMISSION:
-         Log::add_err_va (_("Error: %s"), line.to_string().c_str());
+      case NO_PERMISSION: {
+         std::string cmd (_previous_command);
+         if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
+           cmd.resize (cmd.size()-2);
+         std::string host;
+         _socket->get_host (host);
+         Log::add_err_va (_("Sending \"%s\" to %s returned an error: %s"),
+                          cmd.c_str(),
+                          host.c_str(),
+                          line.to_string().c_str());
+         state = CMD_FAIL;
+         break;
+      }
+
       case NO_SUCH_ARTICLE_NUMBER:
       case NO_SUCH_ARTICLE:
          state = CMD_FAIL;
@@ -237,10 +242,19 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
          state = CMD_RETRY;
          break;
 
-      default:
-         g_message ("I don't know how to handle this: [%s]", line.to_string().c_str());
+      default: {
+         std::string cmd (_previous_command);
+         if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
+           cmd.resize (cmd.size()-2);
+         std::string host;
+         _socket->get_host (host);
+         Log::add_err_va (_("Sending \"%s\" to %s returned an unrecognized response: \"%s\""),
+                          _previous_command.c_str(),
+                          host.c_str(),
+                          line.to_string().c_str());
          state = CMD_FAIL;
          break;
+      }
    }
 
    if ((state == CMD_DONE) && !_commands.empty())
@@ -251,11 +265,11 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
 
    bool more;
    switch (state) {
-      case CMD_FAIL: fire_done_func (FAIL, line); more = false; break;
+      case CMD_FAIL: fire_done_func (COMMAND_FAILED, line); more = false; break;
       case CMD_DONE: if (_commands.empty()) fire_done_func (OK, line); more = false; break;
       case CMD_MORE: more = true; break; // keep listining for more on this command
       case CMD_NEXT: more = false; break; // no more responses on this command; wait for next...
-      case CMD_RETRY: fire_done_func (RETRY, line); more = false; break;
+      case CMD_RETRY: fire_done_func (NETWORK_FAILED, line); more = false; break;
       default: abort(); break;
    }
    return more;
@@ -264,14 +278,14 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
 void
 NNTP :: on_socket_abort (Socket * sock)
 {
-   fire_done_func (FAIL, StringView());
+   fire_done_func (NETWORK_FAILED, StringView());
 }
 
 void
 NNTP :: on_socket_error (Socket * sock)
 {
    _socket_error = true;
-   fire_done_func (RETRY, StringView());
+   fire_done_func (NETWORK_FAILED, StringView());
 }
 
 namespace
